data {
  int<lower=0> N_modern; // number of cases
  int<lower=0> N_fossil; 
  
  real x_meas_modern[N_modern]; // measurement of x
  real x_meas_fossil[N_fossil]; 

  real y_meas_modern[N_modern]; // measurement of y
  real y_meas_fossil[N_fossil]; 
    
  real<lower=0> x_err_modern[N_modern]; // measurement noise x
  real<lower=0> x_err_fossil[N_fossil]; 

  real<lower=0> y_err_modern[N_modern]; // measurement noise y
  real<lower=0> y_err_fossil[N_fossil]; 
  
  // priors for intercepts
  real mu_int_modern; 
  real<lower=0> sigma_int_modern;
  
  real mu_int_fossil;
  real<lower=0> sigma_int_fossil;
  }
parameters {
  real x_modern[N_modern]; // unknown true values x
  real x_fossil[N_fossil]; // 

  real y_modern[N_modern]; // unknown true values y
  real y_fossil[N_fossil]; // 
 
 // intercepts
  real int_modern; 
  real int_fossil; 
  
 // slopes
  real<upper=0> slope_modern; 
  real<lower=0> slope_fossil; // slope fossil constrained > 0
 
 // outcome noise
  real<lower=0> sigma_fossil; 
  real<lower=0> sigma_modern; 
  }
transformed parameters { 
  real<lower = 0> inv_m_blank;
  real m_blank;
  real<lower = 0> F14C_blank;
  inv_m_blank = - (int_fossil - int_modern) / (slope_fossil - slope_modern);
  F14C_blank = int_fossil + slope_fossil * inv_m_blank;
  m_blank = 1/inv_m_blank;
  } 
model {
  // measurement models
  x_meas_modern ~ normal(x_modern, x_err_modern); 
  x_meas_fossil ~ normal(x_fossil, x_err_fossil); 

  y_meas_modern ~ normal(y_modern, y_err_modern); 
  y_meas_fossil ~ normal(y_fossil, y_err_fossil); 
  
  // informative priors on intercepts
  int_modern ~ normal(mu_int_modern, sigma_int_modern);
  int_fossil ~ normal(mu_int_fossil, sigma_int_fossil);
 
  // weak priors on slopes 
  slope_fossil ~ normal(0, 10);
  slope_modern ~ normal(0, 10);
  
  
  // weak priors on error terms
  sigma_fossil ~ cauchy(0, 5);
  sigma_modern ~ cauchy(0, 5);
  

  // Likelihood
  for (i in 1:N_modern)
    y_modern[i] ~ normal(int_modern + slope_modern * x_modern[i], sigma_modern);

  for (i in 1:N_fossil)
    y_fossil[i] ~ normal(int_fossil + slope_fossil * x_fossil[i], sigma_fossil);
  }
